@@ -6,9 +6,9 @@
 #' The methods are asymptotically equivalent. The disequilibrium models are estimated using full
 #' information maximum likelihood. All maximum likelihood models can be estimated both with
 #' independent and correlated demand and supply shocks. The disequilibrium estimation is
-#' based on \href{https://doi.org/10.2307/1914215}{Maddala and Nelson (1974)}. The package is
+#' based on Maddala and Nelson (1974) \doi{10.2307/1914215}. The package is
 #' using the expressions of the gradients of the likelihoods derived in
-#' \href{http://dx.doi.org/10.2139/ssrn.3525622}{Karapanagiotis (2020)}.
+#' Karapanagiotis (2020) \doi{10.2139/ssrn.3525622}.
 #'
 #' @details
 #' ## Usage
@@ -32,8 +32,8 @@
 #' ### Equilibrium model classes:
 #'
 #' \describe{
-#'   \item{\code{\linkS4class{eq_2sls}}}{Equilibrium two-stage least square model}
-#'   \item{\code{\linkS4class{eq_fiml}}}{Equilibrium full information maximum likelihood}
+#'   \item{\code{\linkS4class{equilibrium_model}}}{Equilibrium model that can be estimated
+#' using full information maximum likelihood or two-stage least squares}
 #' }
 #'
 #' ### Disequilibrium model classes:
@@ -52,3 +52,11 @@
 #' @docType package
 #' @name diseq
 NULL
+
+## usethis namespace: start
+#' @useDynLib diseq, .registration = TRUE
+## usethis namespace: end
+NULL
+
+#' @importFrom Rcpp loadModule
+Rcpp::loadModule("diseq_module", TRUE)
