@@ -1,5 +1,8 @@
 context("Stochastic Adjustment Model's Tests\n")
 
+skip_on_cran()
+
+# Estimation setup
 parameters <- list(
     nobs = 2000, tobs = 4,
     alpha_d = -0.1, beta_d0 = 9.8, beta_d = c(0.3, -0.02), eta_d = c(0.6, -0.1),
@@ -8,22 +11,24 @@ parameters <- list(
     sigma_d = 1.0, sigma_s = 1.0, sigma_p = 1.0, rho_ds = 0.0, rho_dp = 0.0, rho_sp = 0.0
 )
 
-mdl <- load_or_simulate_model("diseq_stochastic_adjustment", parameters)
-
-# Estimation setup
+# Optimization setup
 reltol <- 1e-4
 optimization_method <- "BFGS"
-
-skip_on_cran()
-
-# Estimate
 optimization_controls <- list(REPORT = 10, maxit = 50000, reltol = reltol)
-est <- estimate(mdl,
-    control = optimization_controls,
-    method = optimization_method, use_numerical_hessian = TRUE
-)
 
-# Test
+# Tests
+mdl <- NULL
+test_that(paste0("Model can be simulated"), {
+    mdl <<- load_or_simulate_model("diseq_stochastic_adjustment", parameters)
+    expect_is(mdl, "diseq_stochastic_adjustment")
+})
+
+est <- NULL
+test_that(paste0(get_model_description(mdl), " can be estimated"), {
+    est <<- estimate(mdl, control = optimization_controls, method = optimization_method)
+    expect_is(est, "mle2")
+})
+
 test_that(paste0("Estimates of '", get_model_description(mdl), "' are accurate"), {
     test_estimation_accuracy(est@coef, unlist(parameters[-c(1, 2)]), 1e-0)
 })
@@ -36,6 +41,9 @@ test_that(paste0("Mean marginal effect can be calculated"), {
     test_marginal_effect(get_mean_marginal_effect, mdl, est, "P")
     test_marginal_effect(get_mean_marginal_effect, mdl, est, "Xd1")
     test_marginal_effect(get_mean_marginal_effect, mdl, est, "X2")
+    test_marginal_effect(get_marginal_effect_at_mean, mdl, est, "P")
+    test_marginal_effect(get_marginal_effect_at_mean, mdl, est, "Xs1")
+    test_marginal_effect(get_marginal_effect_at_mean, mdl, est, "X2")
 })
 
 test_that(paste0("Aggregation can be calculated"), {
@@ -43,6 +51,11 @@ test_that(paste0("Aggregation can be calculated"), {
     test_aggregation(get_aggregate_supply, mdl, est@coef)
 })
 
+test_that(paste0("Shortages can be calculated"), {
+    test_shortages(get_relative_shortages, mdl, est@coef)
+    test_shortages(get_shortage_probabilities, mdl, est@coef)
+})
+
 test_that(paste0("Scores can be calculated"), {
     test_scores(mdl, est@coef)
 })
